@@ -3,7 +3,7 @@ package namespace::clean;
 use warnings;
 use strict;
 
-our $VERSION = '0.26_01';
+our $VERSION = '0.26_02';
 $VERSION = eval $VERSION if $VERSION =~ /_/; # numify for warning-free dev releases
 
 our $STORAGE_VAR = '__NAMESPACE_CLEAN_STORAGE';
@@ -180,13 +180,9 @@ sub import {
             $store->{remove}{ $f } = 1;
         }
 
-        # register EOF handler on first call to import
-        unless ($store->{handler_is_installed}) {
-            on_scope_end {
-                $RemoveSubs->($cleanee, $store, keys %{ $store->{remove} });
-            };
-            $store->{handler_is_installed} = 1;
-        }
+        on_scope_end {
+            $RemoveSubs->($cleanee, $store, keys %{ $store->{remove} });
+        };
 
         return 1;
     }
@@ -313,10 +309,10 @@ until B<runtime>.
 
 You need to work around this by forcing a compile-time resolution like so:
 
- use MyApp::Utils 'sorter';
+ use MyApp::Utils 'my_sorter';
  use namespace::clean;
 
- my $my_sorter_cref = \&sorter;
+ my $my_sorter_cref = \&my_sorter;
 
  my @sorted = sort $my_sorter_cref @list;
 
